==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/GetChannelFullUrlPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.GetChannelFullUrlPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property channelName Name of the Channel.
 * @property partnerNamespaceName Name of the partner namespace.
 * @property resourceGroupName The name of the resource group within the partners subscription.
 */
public data class GetChannelFullUrlPlainArgs(
    public val channelName: String,
    public val partnerNamespaceName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.GetChannelFullUrlPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.GetChannelFullUrlPlainArgs =
        com.pulumi.azurenative.eventgrid.inputs.GetChannelFullUrlPlainArgs.builder()
            .channelName(channelName.let({ args0 -> args0 }))
            .partnerNamespaceName(partnerNamespaceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetChannelFullUrlPlainArgs].
 */
@PulumiTagMarker
public class GetChannelFullUrlPlainArgsBuilder internal constructor() {
    private var channelName: String? = null

    private var partnerNamespaceName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the Channel.
     */
    @JvmName("hjwcfpkcqdypxrnd")
    public suspend fun channelName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.channelName = mapped
    }

    /**
     * @param value Name of the partner namespace.
     */
    @JvmName("brpukfbknflttmxw")
    public suspend fun partnerNamespaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.partnerNamespaceName = mapped
    }

    /**
     * @param value The name of the resource group within the partners subscription.
     */
    @JvmName("qwlsqywctrmcxlks")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetChannelFullUrlPlainArgs = GetChannelFullUrlPlainArgs(
        channelName = channelName ?: throw PulumiNullFieldException("channelName"),
        partnerNamespaceName = partnerNamespaceName ?: throw
            PulumiNullFieldException("partnerNamespaceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/GetChannelFullUrlPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.GetChannelFullUrlPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property channelName Name of the Channel.
 * @property partnerNamespaceName Name of the partner namespace.
 * @property resourceGroupName The name of the resource group within the partners subscription.
 */
public data class GetChannelFullUrlPlainArgs(
    public val channelName: String,
    public val partnerNamespaceName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.GetChannelFullUrlPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.GetChannelFullUrlPlainArgs =
        com.pulumi.azurenative.eventgrid.inputs.GetChannelFullUrlPlainArgs.builder()
            .channelName(channelName.let({ args0 -> args0 }))
            .partnerNamespaceName(partnerNamespaceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetChannelFullUrlPlainArgs].
 */
@PulumiTagMarker
public class GetChannelFullUrlPlainArgsBuilder internal constructor() {
    private var channelName: String? = null

    private var partnerNamespaceName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the Channel.
     */
    @JvmName("tqhvpnlnimirjctf")
    public suspend fun channelName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.channelName = mapped
    }

    /**
     * @param value Name of the partner namespace.
     */
    @JvmName("sgixnlvpbysqmvll")
    public suspend fun partnerNamespaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.partnerNamespaceName = mapped
    }

    /**
     * @param value The name of the resource group within the partners subscription.
     */
    @JvmName("hgvtuceananuxfme")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetChannelFullUrlPlainArgs = GetChannelFullUrlPlainArgs(
        channelName = channelName ?: throw PulumiNullFieldException("channelName"),
        partnerNamespaceName = partnerNamespaceName ?: throw
            PulumiNullFieldException("partnerNamespaceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
